@@ -68,3 +68,9 @@ def _value_average(node: dict, default=0):
     value = node.get('value')
     is_number = value is not None and (isinstance(value, float) or isinstance(value, int))
     return value if is_number else _average(value, default)
+
+
+def _find_linked_node(nodes: list, linked_node: dict):
+    type = linked_node.get('type')
+    id = linked_node.get('id')
+    return next((node for node in nodes if node['type'] == type and node['id'] == id), None) if type and id else None
