@@ -1,9 +1,9 @@
 from hestia_earth.validation.utils import _flatten
-from .shared import validate_list_duplicates, validate_list_min_max, validate_region, validate_country, \
-    validate_list_term_percent
+from .shared import validate_list_duplicates, validate_list_min_max, validate_region, validate_country
+from .shared import validate_list_term_percent, validate_linked_source_privacy
 
 
-def validate_impact_assessment(impact_assessment: dict):
+def validate_impact_assessment(impact_assessment: dict, nodes=[]):
     """
     Validates a single `ImpactAssessment`.
 
@@ -11,6 +11,8 @@ def validate_impact_assessment(impact_assessment: dict):
     ----------
     impact_assessment : dict
         The `ImpactAssessment` to validate.
+    nodes : list
+        The list of all nodes to do cross-validation.
 
     Returns
     -------
@@ -18,6 +20,7 @@ def validate_impact_assessment(impact_assessment: dict):
         The list of errors for the `ImpactAssessment`, which can be empty if no errors detected.
     """
     return [
+        validate_linked_source_privacy(impact_assessment, 'source', nodes),
         validate_country(impact_assessment) if 'country' in impact_assessment else True,
         validate_region(impact_assessment) if 'region' in impact_assessment else True
     ] + _flatten([
