@@ -2,9 +2,9 @@ from hestia_earth.schema import SiteSiteType
 
 from hestia_earth.validation.utils import _flatten
 from hestia_earth.validation.gee import _fetch_data
-from .shared import validate_dates, validate_list_dates, validate_list_duplicates, \
-    validate_list_min_max, validate_region, validate_country, validate_coordinates, need_validate_coordinates, \
-    validate_area, need_validate_area, validate_list_term_percent
+from .shared import validate_dates, validate_list_dates, validate_list_duplicates, validate_list_min_max
+from .shared import validate_region, validate_country, validate_coordinates, need_validate_coordinates
+from .shared import validate_area, need_validate_area, validate_list_term_percent, validate_linked_source_privacy
 from .infrastructure import validate_lifespan
 from .measurement import validate_soilTexture, validate_depths, validate_value_min_max, validate_term_unique
 from .practice import validate_cropResidueManagement
@@ -62,7 +62,7 @@ def validate_siteType(site: dict):
     }
 
 
-def validate_site(site: dict):
+def validate_site(site: dict, nodes=[]):
     """
     Validates a single `Site`.
 
@@ -70,6 +70,8 @@ def validate_site(site: dict):
     ----------
     site : dict
         The `Site` to validate.
+    nodes : list
+        The list of all nodes to do cross-validation.
 
     Returns
     -------
@@ -78,6 +80,7 @@ def validate_site(site: dict):
     """
     return [
         validate_site_dates(site),
+        validate_linked_source_privacy(site, 'defaultSource', nodes),
         validate_siteType(site) if need_validate_coordinates(site) else True,
         validate_country(site) if 'country' in site else True,
         validate_region(site) if 'region' in site else True,
